@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use Storable;
+use Storable qw( retrieve store );
 
 if (@ARGV && $ARGV[0] eq "store") {
     require URI;
@@ -11,17 +11,16 @@ if (@ARGV && $ARGV[0] eq "store") {
     print "# store\n";
     store [URI->new("http://search.cpan.org")], 'urls.sto';
 } else {
-    print "# retrieve\n";
+    require Test::More;
+    Test::More->import(tests => 3);
+    note("retrieve");
     my $a = retrieve 'urls.sto';
     my $u = $a->[0];
     #use Data::Dumper; print Dumper($a);
 
-    print "not " unless $u eq "http://search.cpan.org";
-    print "ok 1\n";
+    is($u, "http://search.cpan.org");
 
-    print "not " unless $u->scheme eq "http";
-    print "ok 2\n";
+    is($u->scheme, "http");
 
-    print "not " unless ref($u) eq "URI::http";
-    print "ok 3\n";
+    is(ref($u), "URI::http");
 }
